@@ -5,7 +5,7 @@ import math
 import os
 import sys
 from pathlib import Path
-from typing import Dict, NamedTuple
+from typing import NamedTuple
 
 import pytest
 
@@ -66,7 +66,7 @@ class TypeCase(NamedTuple):
 
 
 # fmt: off
-TYPE_CASES: Dict[str, TypeCase] = {
+TYPE_CASES: dict[str, TypeCase] = {
     "variable": TypeCase(
         document="test = 1\ntes",
         position={"line": 1, "character": 3},
@@ -282,8 +282,8 @@ def test_jedi_method_completion(config, workspace) -> None:
     reason="Test in Python 3 and not on CIs on Linux because wheels don't work on them.",
 )
 def test_pyqt_completion(config, workspace) -> None:
-    # Over 'QA' in 'from PyQt5.QtWidgets import QApplication'
-    doc_pyqt = "from PyQt5.QtWidgets import QA"
+    # Over 'QA' in 'from PyQt6.QtWidgets import QApplication'
+    doc_pyqt = "from PyQt6.QtWidgets import QA"
     com_position = {"line": 0, "character": len(doc_pyqt)}
     doc = Document(DOC_URI, workspace, doc_pyqt)
     completions = pylsp_jedi_completions(config, doc, com_position)
